@@ -17,7 +17,7 @@
 
 #ifndef KSTARS_KSPARSER_H
 #define KSTARS_KSPARSER_H
-#include "kstars/auxiliary/ksfilereader.h"
+
 #include <QStandardPaths>
 #include <QList>
 #include <QFile>
@@ -25,6 +25,8 @@
 #include <QDebug>
 #include <QVariant>
 
+#include "ksfilereader.h"
+
 /**
  * @brief Generic class for text file parsers used in KStars.
  * Read rows using ReadCSVRow() regardless of the type of parser.
