@@ -32,11 +32,14 @@ FocusDialogUI::FocusDialogUI( QWidget *parent ) : QFrame( parent ) {
     setupUi( this );
 }
 
-FocusDialog::FocusDialog( KStars *_ks )
-        : QDialog( _ks ), ks( _ks )
+FocusDialog::FocusDialog()
+        : QDialog(KStars::Instance())
 {
+#ifdef Q_OS_OSX
+        setWindowFlags(Qt::Tool| Qt::WindowStaysOnTopHint);
+#endif
     //initialize point to the current focus position
-    Point = *ks->map()->focus();
+    Point = SkyMap::Instance()->focus();
 
     UsedAltAz = false; //assume RA/Dec by default
 
@@ -72,26 +75,33 @@ FocusDialog::FocusDialog( KStars *_ks )
 FocusDialog::~FocusDialog(){
 }
 
-void FocusDialog::checkLineEdits() {
+void FocusDialog::checkLineEdits()
+{
     bool raOk(false), decOk(false), azOk(false), altOk(false);
+
     fd->raBox->createDms( false, &raOk );
     fd->decBox->createDms( true, &decOk );
     fd->azBox->createDms( true, &azOk );
     fd->altBox->createDms( true, &altOk );
 
     if ( ( raOk && decOk ) || ( azOk && altOk ) )
-        okB->setEnabled(true );
+        okB->setEnabled(true);
     else
         okB->setEnabled(false);
 }
 
-void FocusDialog::validatePoint() {
+void FocusDialog::validatePoint()
+{
     bool raOk(false), decOk(false), azOk(false), altOk(false);
-    dms ra( fd->raBox->createDms( false, &raOk ) ); //false means expressed in hours
+
+     //false means expressed in hours
+    dms ra( fd->raBox->createDms( false, &raOk ) );
     dms dec( fd->decBox->createDms( true, &decOk ) );
+
     QString message;
 
-    if ( raOk && decOk ) {
+    if ( raOk && decOk )
+    {
         //make sure values are in valid range
         if ( ra.Hours() < 0.0 || ra.Hours() > 24.0 )
             message = i18n( "The Right Ascension value must be between 0.0 and 24.0." );
@@ -102,11 +112,13 @@ void FocusDialog::validatePoint() {
             return;
         }
 
-        Point.set( ra, dec );
-        double epoch0 = getEpoch( fd->epochBox->text() );
-        long double jd0 = epochToJd ( epoch0 );
-        Point.apparentCoord(jd0, ks->data()->ut().djd() );
-        Point.EquatorialToHorizontal( ks->data()->lst(), ks->data()->geo()->lat() );
+        Point->set( ra, dec );
+        bool ok;
+
+        double epoch0 = KStarsDateTime::stringToEpoch( fd->epochBox->text(), ok );
+        long double jd0 = KStarsDateTime::epochToJd ( epoch0 );
+        Point->apparentCoord(jd0, KStarsData::Instance()->ut().djd() );
+        Point->EquatorialToHorizontal( KStarsData::Instance()->lst(), KStarsData::Instance()->geo()->lat() );
 
         QDialog::accept();
     } else {
@@ -124,9 +136,9 @@ void FocusDialog::validatePoint() {
                 return;
             }
 
-            Point.setAz( az );
-            Point.setAlt( alt );
-            Point.HorizontalToEquatorial( ks->data()->lst(), ks->data()->geo()->lat() );
+            Point->setAz( az );
+            Point->setAlt( alt );
+            Point->HorizontalToEquatorial( KStarsData::Instance()->lst(), KStarsData::Instance()->geo()->lat() );
 
             UsedAltAz = true;
 
@@ -137,31 +149,6 @@ void FocusDialog::validatePoint() {
     }
 }
 
-double FocusDialog::getEpoch (const QString &eName) {
-    //If eName is empty (or not a number) assume 2000.0
-    bool ok(false);
-    double epoch = eName.toDouble( &ok );
-    if ( eName.isEmpty() || ! ok )
-        return 2000.0;
-
-    return epoch;
-}
-
-long double FocusDialog::epochToJd (double epoch) {
-
-    double yearsTo2000 = 2000.0 - epoch;
-
-    if (epoch == 1950.0) {
-        return 2433282.4235;
-    } else if ( epoch == 2000.0 ) {
-        return J2000;
-    } else {
-        return ( J2000 - yearsTo2000 * 365.2425 );
-    }
-
-}
-
-
 QSize FocusDialog::sizeHint() const
 {
     return QSize(240,210);
