@@ -41,6 +41,9 @@ LocationDialogUI::LocationDialogUI( QWidget *parent ) : QFrame( parent )
 LocationDialog::LocationDialog( QWidget* parent ) :
     QDialog( parent ), timer( 0 )
 {
+#ifdef Q_OS_OSX
+        setWindowFlags(Qt::Tool| Qt::WindowStaysOnTopHint);
+#endif
     KStarsData* data = KStarsData::Instance();
 
     SelectedCity = NULL;
@@ -68,9 +71,9 @@ LocationDialog::LocationDialog( QWidget* parent ) :
             ld->DSTRuleBox->addItem( key );
     }
 
-    ld->AddCityButton->setIcon(QIcon::fromTheme("list-add"));
-    ld->RemoveButton->setIcon(QIcon::fromTheme("list-remove"));
-    ld->UpdateButton->setIcon(QIcon::fromTheme("svn-update"));
+    ld->AddCityButton->setIcon(QIcon::fromTheme("list-add", QIcon(":/icons/breeze/default/list-add.svg")));
+    ld->RemoveButton->setIcon(QIcon::fromTheme("list-remove", QIcon(":/icons/breeze/default/list-remove.svg")));
+    ld->UpdateButton->setIcon(QIcon::fromTheme("svn-update", QIcon(":/icons/breeze/default/svn-update.svg")));
 
     connect( ld->CityFilter, SIGNAL( textChanged( const QString & ) ), this, SLOT( enqueueFilterCity() ) );
     connect( ld->ProvinceFilter, SIGNAL( textChanged( const QString & ) ), this, SLOT( enqueueFilterCity() ) );
