@@ -148,9 +148,9 @@ public:
 
     /** DBUS interface function.
      * Set guiding algorithm. The options must be set before starting the guiding operation. If no options are set, the options loaded from the user configuration are used.
-     * @param algorithm Select the algorithm used to calculate the centroid of the guide star (Smart, Fast, Auto, No thresh).
+     * @param index Select the algorithm used to calculate the centroid of the guide star (0 --> Smart, 1 --> Fast, 2 --> Auto, 3 --> No thresh).
      */
-    Q_SCRIPTABLE Q_NOREPLY void setGuideAlgorithm(const QString & algorithm);    
+    Q_SCRIPTABLE Q_NOREPLY void setGuideAlgorithmIndex(int index);
 
     /** DBUS interface function.
      * Set rapid guiding option. The options must be set before starting the guiding operation. If no options are set, the options loaded from the user configuration are used.
@@ -373,7 +373,9 @@ protected slots:
 
      void processGuideOptions();
 
-     void onControlDirectionChanged(bool enable);     
+     void onControlDirectionChanged(bool enable);
+
+     void showFITSViewer();
 
 signals:
     void newLog();
@@ -383,6 +385,7 @@ signals:
     void newProfilePixmap(QPixmap &);
 
     void newAxisDelta(double delta_ra, double delta_dec);
+    void sigmasUpdated(double ra, double dec);
     void guideChipUpdated(ISD::CCDChip*);
 
 private:
@@ -412,8 +415,6 @@ private:
      */
     void setBusy(bool enable);
 
-    void updateCCDBlobMode(int type);
-
     // Operation stack
     void buildOperationStack(GuideState operation);
     bool executeOperationStack();
@@ -497,6 +498,7 @@ private:
     QPointer<InternalGuider> internalGuider;
     QPointer<PHD2> phd2Guider;
     QPointer<LinGuider> linGuider;
+    QPointer<FITSViewer> fv;
 };
 
 }
