@@ -339,18 +339,20 @@ void SchedulerJob::setFileStartupCondition(const StartupCondition &value)
 {
     fileStartupCondition = value;
 }
-double SchedulerJob::getEstimatedTime() const
+
+int64_t SchedulerJob::getEstimatedTime() const
 {
     return estimatedTime;
 }
 
-void SchedulerJob::setEstimatedTime(const double &value)
+void SchedulerJob::setEstimatedTime(const int64_t &value)
 {
     estimatedTime = value;
 
     if (estimatedTimeCell)
     {
-        QTime estimatedTime = QTime::fromMSecsSinceStartOfDay(value*3600);
+        // Seconds to ms
+        QTime estimatedTime = QTime::fromMSecsSinceStartOfDay(value*1000);
         estimatedTimeCell->setText(estimatedTime.toString("HH:mm:ss"));
     }
 }
@@ -414,6 +416,36 @@ void SchedulerJob::setEstimatedTimeCell(QTableWidgetItem *value)
     estimatedTimeCell = value;
 }
 
+bool SchedulerJob::getLightFramesRequired() const
+{
+    return lightFramesRequired;
+}
+
+void SchedulerJob::setLightFramesRequired(bool value)
+{
+    lightFramesRequired = value;
+}
+
+uint16_t SchedulerJob::getRepeatsRequired() const
+{
+    return repeatsRequired;
+}
+
+void SchedulerJob::setRepeatsRequired(const uint16_t &value)
+{
+    repeatsRequired = value;
+}
+
+uint16_t SchedulerJob::getRepeatsRemaining() const
+{
+    return repeatsRemaining;
+}
+
+void SchedulerJob::setRepeatsRemaining(const uint16_t &value)
+{
+    repeatsRemaining = value;
+}
+
 
 
 void SchedulerJob::setTargetCoords(dms ra, dms dec)
