@@ -145,7 +145,7 @@ FITSViewer::FITSViewer (QWidget *parent)
     action = actionCollection()->addAction("image_histogram");
     action->setText(i18n("Histogram"));
     connect(action, SIGNAL(triggered(bool)), SLOT (histoFITS()));
-    actionCollection()->setDefaultShortcut(action, QKeySequence::Replace);
+    actionCollection()->setDefaultShortcut(action, QKeySequence(Qt::CTRL+Qt::Key_T));
 
     action->setIcon(QIcon(":/icons/histogram.png"));
 
@@ -286,6 +286,9 @@ void FITSViewer::changeAlwaysOnTop(Qt::ApplicationState state)
 
 FITSViewer::~FITSViewer()
 {
+    if (KStars::Instance())
+        KStars::Instance()->getFITSViewersList().removeOne(this);
+
     fitsTab->disconnect();
 
     qDeleteAll(fitsTabs);
@@ -320,7 +323,7 @@ void FITSViewer::hideEvent(QHideEvent * /*event*/)
         {
             QList<FITSViewer *> viewers = KStars::Instance()->findChildren<FITSViewer *>();
 
-            if (viewers.count() == 1)
+            if (viewers.count() <= 1)
                 a->setChecked(false);
         }
     }
@@ -363,6 +366,12 @@ int FITSViewer::addFITS(const QUrl *imageName, FITSMode mode, FITSScale filter,
     QApplication::restoreOverrideCursor();
     tab->setPreviewText(previewText);
 
+    connect(tab, SIGNAL(newStatus(QString,FITSBar)), this, SLOT(updateStatusBar(QString,FITSBar)));
+    connect(tab->getView(), SIGNAL(actionUpdated(QString,bool)), this, SLOT(updateAction(QString,bool)));
+    connect(tab, SIGNAL(changeStatus(bool)), this, SLOT(updateTabStatus(bool)));
+    connect(tab, SIGNAL(debayerToggled(bool)), this, SLOT(setDebayerAction(bool)));
+    connect(tab->getView(), SIGNAL(wcsToggled(bool)), this, SLOT(updateWCSFunctions()));
+
     switch (mode)
     {
       case FITS_NORMAL:
@@ -390,12 +399,6 @@ int FITSViewer::addFITS(const QUrl *imageName, FITSMode mode, FITSScale filter,
 
     }
 
-    connect(tab, SIGNAL(newStatus(QString,FITSBar)), this, SLOT(updateStatusBar(QString,FITSBar)));
-    connect(tab->getView(), SIGNAL(actionUpdated(QString,bool)), this, SLOT(updateAction(QString,bool)));
-    connect(tab, SIGNAL(changeStatus(bool)), this, SLOT(updateTabStatus(bool)));
-    connect(tab, SIGNAL(debayerToggled(bool)), this, SLOT(setDebayerAction(bool)));
-    connect(tab->getView(), SIGNAL(wcsToggled(bool)), this, SLOT(updateWCSFunctions()));
-
     saveFileAction->setEnabled(true);
     saveFileAsAction->setEnabled(true);
 
@@ -909,9 +912,11 @@ void FITSViewer::updateScopeButton(){
  */
 
 void FITSViewer::centerTelescope(){
+    getCurrentView()->setScopeButton(actionCollection()->action("center_telescope"));
     if(getCurrentView()->getMouseMode()==FITSView::scopeMouse){
-        getCurrentView()->setMouseMode(FITSView::dragMouse);
+        getCurrentView()->setMouseMode(getCurrentView()->lastMouseMode);
     } else{
+        getCurrentView()->lastMouseMode=getCurrentView()->getMouseMode();
         getCurrentView()->setMouseMode(FITSView::scopeMouse);
     }
     updateScopeButton();
