@@ -57,6 +57,7 @@ public:
     bool getFrame(int *x, int *y, int *w, int *h);
     bool getFrameMinMax(int *minX, int *maxX, int *minY, int *maxY, int *minW, int *maxW, int *minH, int *maxH);
     bool setFrame(int x, int y, int w, int h);
+
     //bool getFocusFrame(int *x, int *y, int *w, int *h);
     //bool setFocusFrame(int x, int y, int w, int h);
     bool resetFrame();
@@ -72,6 +73,11 @@ public:
     ChipType getType() const { return type; }
     ISD::CCD *getCCD() { return parentCCD;}
 
+    // Set Image Info
+    bool setImageInfo(uint16_t width, uint16_t height, double pixelX, double pixelY, uint8_t bitdepth);
+    // Get Pixel size
+    bool getPixelSize(double &x, double &y);
+
     bool isCapturing();
     bool abortExposure();
 
@@ -136,7 +142,9 @@ public:
     ~CCD();
 
     typedef enum { UPLOAD_CLIENT, UPLOAD_LOCAL, UPLOAD_BOTH } UploadMode;
+    typedef enum { FORMAT_FITS, FORMAT_NATIVE } TransferFormat;
     enum BlobType { BLOB_IMAGE, BLOB_FITS, BLOB_RAW, BLOB_OTHER} BType;
+    typedef enum { TELESCOPE_PRIMARY, TELESCOPE_GUIDE } TelescopeType;
 
     void registerProperty(INDI::Property *prop);
     void processSwitch(ISwitchVectorProperty *svp);
@@ -149,6 +157,7 @@ public:
     bool hasGuideHead();
     bool hasCooler();
     bool hasCoolerControl();
+    bool hasVideoStream() { return HasVideoStream; }
     bool setCoolerControl(bool enable);
 
     // Utitlity functions
@@ -158,16 +167,45 @@ public:
     void setSeqPrefix(const QString &preFix) { seqPrefix = preFix; }
     void setNextSequenceID(int count) { nextSequenceID = count; }
     void setFilter(const QString & newFilter) { filter = newFilter;}
+
+    // Rapid Guide
     bool configureRapidGuide(CCDChip *targetChip, bool autoLoop, bool sendImage=false, bool showMarker=false);
     bool setRapidGuide(CCDChip *targetChip, bool enable);
+
+    // Upload Settings
     void updateUploadSettings(const QString &remoteDir);
     UploadMode getUploadMode();
     bool setUploadMode(UploadMode mode);
 
+    // Transfer Format
+    TransferFormat getTransferFormat() { return transferFormat; }
+    bool setTransformFormat(CCD::TransferFormat format);
+
+    // Video Stream
+    bool setVideoStreamEnabled(bool enable);
+    bool resetStreamingFrame();
+    bool setStreamingFrame(int x, int y, int w, int h);
+    bool isStreamingEnabled();
+
+    // Video Recording
+    bool setSERNameDirectory(const QString &filename, const QString &directory);
+    bool getSERNameDirectory(QString &filename, QString &directory);
+    bool startRecording();
+    bool startDurationRecording(double duration);
+    bool startFramesRecording(uint32_t frames);
+    bool stopRecording();
+
+    // Telescope type
+    TelescopeType getTelescopeType() { return telescopeType; }
+    bool setTelescopeType(TelescopeType type);
+
     FITSViewer *getViewer() { return fv;}
     CCDChip * getChip(CCDChip::ChipType cType);
     void setFITSDir(const QString &dir) { fitsDir = dir;}
 
+    TransferFormat getTargetTransferFormat() const;
+    void setTargetTransferFormat(const TransferFormat &value);
+
 public slots:
     void FITSViewerDestroyed();
     void StreamWindowHidden();
@@ -179,6 +217,9 @@ signals:
     void newGuideStarData(ISD::CCDChip *chip, double dx, double dy, double fit);
     void newRemoteFile(QString);
     void newImage(QImage *image, ISD::CCDChip *targetChip);
+    void videoStreamToggled(bool enabled);
+    void videoRecordToggled(bool enabled);
+    void newFPS(double instantFPS, double averageFPS);
 
 private:
     void addFITSKeywords(QString filename);
@@ -188,6 +229,7 @@ private:
     bool HasGuideHead;
     bool HasCooler;
     bool HasCoolerControl;
+    bool HasVideoStream;
     QString		seqPrefix;
     QString     fitsDir;
     char BLOBFilename[MAXINDIFILENAME];
@@ -197,6 +239,8 @@ private:
     ISD::ST4 *ST4Driver;
     int normalTabID, calibrationTabID, focusTabID, guideTabID, alignTabID;
     CCDChip *primaryChip, *guideChip;
+    TransferFormat transferFormat, targetTransferFormat;
+    TelescopeType telescopeType = TELESCOPE_PRIMARY;
 
     QPointer<FITSViewer> fv;
     QPointer<ImageViewer> imageViewer;
