@@ -62,6 +62,9 @@
 DeviceManagerUI::DeviceManagerUI(QWidget *parent) : QFrame(parent)
 {
 
+#ifdef Q_OS_OSX
+        setWindowFlags(Qt::Tool| Qt::WindowStaysOnTopHint);
+#endif
     setupUi(this);
 
     localTreeWidget->setSortingEnabled(false);
@@ -494,9 +497,15 @@ bool INDIDriver::readXMLDrivers()
     QDir indiDir;
     QString driverName;
 
-    if (indiDir.cd(Options::indiDriversDir()) == false)
+    QString driversDir=Options::indiDriversDir();
+     #ifdef Q_OS_OSX
+    if(Options::indiDriversAreInternal())
+        driversDir=QCoreApplication::applicationDirPath()+"/indi";
+    #endif
+
+    if (indiDir.cd(driversDir) == false)
     {
-        KMessageBox::error(0, xi18n("Unable to find INDI Drivers directory: %1\nPlease make sure to set the correct path in KStars configuration", Options::indiDriversDir()));
+        KMessageBox::error(0, xi18n("Unable to find INDI Drivers directory: %1\nPlease make sure to set the correct path in KStars configuration", driversDir));
           return false;
      }
 
@@ -513,7 +522,7 @@ bool INDIDriver::readXMLDrivers()
 	if (fileInfo.fileName() == "drivers.xml")
 	{ 
 	    // Let first attempt to load the local version of drivers.xml
-	    driverName = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "drivers.xml";
+	    driverName = KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "drivers.xml";
 
 	    // If found, we continue, otherwise, we load the system file
 	    if (driverName.isEmpty() == false && QFile(driverName).exists())
@@ -523,7 +532,7 @@ bool INDIDriver::readXMLDrivers()
 	    }
 	}
 
-	        driverName = QString("%1/%2").arg(Options::indiDriversDir()).arg(fileInfo.fileName());
+            driverName = QString("%1/%2").arg(driversDir).arg(fileInfo.fileName());
 	        processXMLDriver(driverName);
 
     }
@@ -929,7 +938,7 @@ void INDIDriver::saveHosts()
     QFile file;
     QString hostData;
 
-    file.setFileName( QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "indihosts.xml" ) ; //determine filename in local user KDE directory tree.
+    file.setFileName( KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + "indihosts.xml" ) ; //determine filename in local user KDE directory tree.
 
     if ( !file.open( QIODevice::WriteOnly))
     {
