@@ -46,10 +46,11 @@ public:
 
     int size() { return devices.size(); }
 
-    bool isStandardProperty(const QString &name);   
+    bool isStandardProperty(const QString &name);
 
   private:
-    INDIListener();
+    INDIListener(QObject *parent);
+    ~INDIListener();
     static INDIListener * _INDIListener;
     QList<ClientManager *> clients;
     QList<ISD::GDInterface *> devices;
